@@ -1,6 +1,6 @@
 package Elastic::Doc;
 {
-  $Elastic::Doc::VERSION = '0.26';
+  $Elastic::Doc::VERSION = '0.27';
 }
 
 use Moose();
@@ -69,7 +69,7 @@ Elastic::Doc - Adds Elastic::Model functionality to your object classes
 
 =head1 VERSION
 
-version 0.26
+version 0.27
 
 =head1 SYNOPSIS
 
@@ -133,7 +133,7 @@ version 0.26
 =head1 DESCRIPTION
 
 Elastic::Doc prepares your object classes (eg C<MyApp::User>) for storage in
-ElasticSearch, by:
+Elasticsearch, by:
 
 =over
 
@@ -155,7 +155,7 @@ L<Elastic::Model::Meta::Instance>).
 =item *
 
 exporting the L</"has_mapping"> function to allow you to customize the
-special "meta-fields" in the type mapping in ElasticSearch
+special "meta-fields" in the type mapping in Elasticsearch
 
 =back
 
@@ -191,8 +191,8 @@ attr/field-specific) in the type mapping. For instance:
 B<Warning:> Use C<has_mapping> with caution. L<Elastic::Model> requires
 certain settings to be active to work correctly.
 
-See the "Fields" section in L<Mapping|http://www.elasticsearch.org/guide/reference/mapping/> and
-L<Root object type|http://www.elasticsearch.org/guide/reference/mapping/root-object-type.html>
+See the "Fields" section in L<Mapping|http://www.Elasticsearch.org/guide/reference/mapping/> and
+L<Root object type|http://www.Elasticsearch.org/guide/reference/mapping/root-object-type.html>
 for more information about what options can be configured.
 
 =head2 apply_field_settings
